#### Subports

Select an arbitrary amount of ports (0, 1, 2, ...) and their segmentation details as the subports of the trunk to be created. Optional.

Loading ports... Please Wait

| Name | IP | Admin State | Status | Segmentation Type | Segmentation Id |
--- | --- | --- | --- | --- | --- | --- | ---
Select items from Available items below
| {$ ctrl.nameOrID(item) $} | {$ ip.ip_address $} on subnet: {$ item.subnet_names[ip.ip_address] $} | {$ item.admin_state | decode:ctrl.portAdminStates $} | {$ item.status | decode:ctrl.portStatuses $} |  | inherit |  |
ID {$ item.id $} Project ID {$ item.tenant_id $} Network ID {$ item.network_id $} Network {$ item.network_name $} MAC Address {$ item.mac_address $} VNIC type {$ item['binding:vnic_type'] | decode:ctrl.vnicTypes $} Host ID {$ item['binding:host_id'] $}

| Name | IP | Admin State | Status |
--- | --- | --- | --- | --- | ---
No available items
| {$ ctrl.nameOrID(item) $} | {$ ip.ip_address $} on subnet: {$ item.subnet_names[ip.ip_address] $} | {$ item.admin_state | decode:ctrl.portAdminStates $} | {$ item.status | decode:ctrl.portStatuses $} |
ID {$ item.id $} Project ID {$ item.tenant_id $} Network ID {$ item.network_id $} Network {$ item.network_name $} MAC Address {$ item.mac_address $} VNIC type {$ item['binding:vnic_type'] | decode:ctrl.vnicTypes $} Host ID {$ item['binding:host_id'] $}